summaryrefslogtreecommitdiffstats
path: root/sys/netgraph/ng_parse.h
diff options
context:
space:
mode:
authorarchie <archie@FreeBSD.org>2000-03-13 18:50:38 +0000
committerarchie <archie@FreeBSD.org>2000-03-13 18:50:38 +0000
commitea3525dea40ecd01441827e6d2185f4088d4d997 (patch)
treee6316dd6ea770c08a008ce48b8a744c6835033bc /sys/netgraph/ng_parse.h
parent1d2318b7df5af3e84c4f90637b1accb6a8925dd0 (diff)
downloadFreeBSD-src-ea3525dea40ecd01441827e6d2185f4088d4d997.zip
FreeBSD-src-ea3525dea40ecd01441827e6d2185f4088d4d997.tar.gz
Fix typo: "ng_parse_fixedsstring_info" -> "ng_parse_fixedstring_info"
Diffstat (limited to 'sys/netgraph/ng_parse.h')
-rw-r--r--sys/netgraph/ng_parse.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/netgraph/ng_parse.h b/sys/netgraph/ng_parse.h
index 0dbf769..1543c6b 100644
--- a/sys/netgraph/ng_parse.h
+++ b/sys/netgraph/ng_parse.h
@@ -126,7 +126,7 @@
type for the whole structure ('//' comments used to avoid breakage).
// Super-type info for 'label' field
- struct ng_parse_fixedsstring_info foo_label_info = { 8 };
+ struct ng_parse_fixedstring_info foo_label_info = { 8 };
// Parse type for 'label' field
struct ng_parse_type foo_label_type = {
@@ -385,11 +385,11 @@ extern const struct ng_parse_type ng_parse_string_type;
* a terminating NUL character.
*
* Default value: Empty string
* Additional info: struct ng_parse_fixedsstring_info *
*/
extern const struct ng_parse_type ng_parse_fixedstring_type;
-struct ng_parse_fixedsstring_info {
+struct ng_parse_fixedstring_info {
int bufSize; /* size of buffer (including NUL) */
};
OpenPOWER on IntegriCloud
@@ -385,11 +385,11 @@ extern const struct ng_parse_type ng_parse_string_type;
*
* Default value: Empty string
- * Additional info: struct ng_parse_fixedsstring_info *
+ * Additional info: struct ng_parse_fixedstring_info *
*/
extern const struct ng_parse_type ng_parse_fixedstring_type;